@@ -1,6 +1,6 @@
 package Text::PDF::API;
 
-$VERSION = "0.699_82";
+$VERSION = "0.699_83";
 
 use Text::PDF::File;
 use Text::PDF::AFont;
@@ -37,8 +37,8 @@ use Text::PDF::API::UniMap;
 
 sub genKEY {
         my $key=join(',',@_);
-	use Digest::REHLHA qw( rehlha0_16 );
-	$key=rehlha0_16($key);
+	use Text::PDF::API::REHLHA qw( rehlha_16 );
+	$key=rehlha_16($key);
         return($key);
 }
 
@@ -1835,7 +1835,28 @@ parameter with $pdf->newFont
 If you do not give $encoding, than the encoding from $pdf->newFont??? is used.
 
 B<NOTE:> As of version API 0.699 you can specify the following encodings:
-adobe-standard adobe-symbol adobe-zapf-dingbats cp1250 cp1251 cp1252 cp1253 cp1254 cp1255 cp1256 cp1257 cp1258 cp437 cp850 ebcdic-at-de ebcdic-at-de-a ebcdic-ca-fr ebcdic-dk-no ebcdic-dk-no-a ebcdic-es ebcdic-es-a ebcdic-es-s ebcdic-fi-se ebcdic-fi-se-a ebcdic-fr ebcdic-it ebcdic-pt ebcdic-uk ebcdic-us latin1 latin13 latin15 latin2 latin3 latin4 latin5 latin6 latin7 latin8 microsoft-dingbats
+adobe-standard adobe-symbol adobe-zapf-dingbats ansi-x3-110-1983 ansi-x3-4-1968 asmo-449
+bs-4730 bs-viewdata cp037 cp10000 cp10006 cp10007 cp10029 cp10079 cp10081 cp1026 cp1250
+cp1251 cp1252 cp1253 cp1254 cp1255 cp1256 cp1257 cp1258 cp437 cp500 cp737 cp775 cp850
+cp852 cp855 cp857 cp860 cp861 cp862 cp863 cp864 cp865 cp866 cp866lr cp869 cp874 cp875
+csa-z243-4-1985-1 csa-z243-4-1985-2 csa-z243-4-1985-gr csn-369103 dec-mcs din-66003 dk-us
+ds-2089 ebcdic-at-de-a ebcdic-at-de ebcdic-ca-fr ebcdic-dk-no-a ebcdic-dk-no ebcdic-es-a
+ebcdic-es-s ebcdic-es ebcdic-fi-se-a ebcdic-fi-se ebcdic-fr ebcdic-it ebcdic-pt
+ebcdic-uk ebcdic-us ecma-cyrillic es es2 gb-1988-80 gost-19768-74 greek-ccitt
+greek7-old greek7 hp-roman8 ibm037 ibm038 ibm1026 ibm273 ibm274 ibm275 ibm277 ibm278
+ibm280 ibm281 ibm284 ibm285 ibm290 ibm297 ibm420 ibm424 ibm437 ibm500 ibm850 ibm851
+ibm852 ibm855 ibm857 ibm860 ibm861 ibm862 ibm863 ibm864 ibm865 ibm868 ibm869 ibm870
+ibm871 ibm880 ibm891 ibm903 ibm904 ibm905 ibm918 iec-p27-1 inis-8 inis-cyrillic inis
+invariant iso-10367-box iso-2033-1983 iso-5427 iso-5428 iso-646-basic iso-646-irv
+iso-6937-2-25 iso-6937-2-add iso-8859-1 iso-8859-13 iso-8859-15 iso-8859-2 iso-8859-3
+iso-8859-4 iso-8859-5 iso-8859-6 iso-8859-7 iso-8859-8 iso-8859-9 iso-8859-supp
+iso-ir-90 it jis-c6220-1969-jp jis-c6220-1969-ro jis-c6229-1984-a jis-c6229-1984-b-add
+jis-c6229-1984-b jis-c6229-1984-hand-add jis-c6229-1984-hand jis-c6229-1984-kana
+jis-x0201 jus-i-b1-002 jus-i-b1-003-mac jus-i-b1-003-serb koi8-r koi8-u ksc5636
+latin-greek-1 latin-greek latin-lap latin1 latin13 latin15 latin2 latin3 latin4 latin5
+latin6 latin7 latin8 macintosh microsoft-dingbats msz-7795-3 nats-dano-add nats-dano
+nats-sefi-add nats-sefi nc-nc00-10 nf-z-62-010 ns-4551-1 ns-4551-2 pt pt2 sen-850200-b
+sen-850200-c t-101-g2 t-61-7bit t-61-8bit us-dk videotex-suppl
 
 B<NOTE:> The fonts are automagically reencoded to use the new encoding if it differs
 from that encoding specified at $pdf->newFont???.
@@ -2320,6 +2341,11 @@ Implemetation of a testing-suite, code cleanups , rewitten bitmap-image handling
 for more modular structure , JPEG is now a native image-format (the usage of 
 the jpeg-plugin is strongly discouraged) with the same limitations as the XS version.
 
+=item Version 0.699_8?
+
+cleaned up image functions to use x-o's and streamlined key-generation to
+compensate an arkward behavior of the Text::PDF pdf-parser.
+
 =back
 
 =head1 CONTRIBUTORS / BUGHUNTERS / THANKS
@@ -2333,8 +2359,8 @@ Lester Hightower [hightowe@TheAIMSGroup.com]
 =head1 PLUG-INS
 
 As of Version 0.604 bitmapped image loading functions can be extended
-via XS modules.  Currently available: Text-PDF-API-JPEG, Text-PDF-API-GIF, 
-Text-PDF-API-PPM and Text-PDF-API-BMP (little-endian only).
+via XS modules.  Currently available: Text-PDF-API-GIF, Text-PDF-API-PPM 
+and Text-PDF-API-BMP (little-endian only).
 
 =head1 BUGS
 
